//
//  LFLivenessEnumType.h
//  LFLivenessDetector
//
//  Copyright (c) 2017-2018 LINKFACE Corporation. All rights reserved.
//

#ifndef LFLivenessEnumType_h
#define LFLivenessEnumType_h


/**
 *  活体检测失败类型
 */
typedef NS_ENUM(NSInteger, LivefaceErrorType) {
    
    /**
     *  算法SDK初始化失败
     */
    LIVENESS_INIT_FAILD = 0,
    
    /**
     *  相机权限获取失败
     */
    LIVENESS_CAMERA_ERROR,
    
    /**
     *  token验证未通过，无效token
     */
    LIVENESS_TOKEN_INVALID,
    
    /**
     *  token验证未通过，bundle_id未绑定
     */
    LIVENESS_TOKEN_UNBOUND,
    
    /**
     *  token验证失败
     */
    LIVENESS_TOKEN_ERROR,
    
    /**
     *  人脸变更
     */
    LIVENESS_FACE_CHANGED,
    
    /**
     *  检测超时
     */
    LIVENESS_TIMEOUT,
    
    /**
     *  应用即将被挂起
     */
    LIVENESS_WILL_RESIGN_ACTIVE,
    
    /**
     *  内部错误
     */
    LIVENESS_INTERNAL_ERROR,
    
    /**
     * 其他错误
     */
    LINENESS_OTHER_ERROR,
    
    /**
     *  中途人脸变更
     */
    LIVENESS_FACE_CHANGED_WAY,
    
};

typedef NS_ENUM(NSInteger,LivefaceChangeValue){
    /**
     * 没有人脸
     */
    LIVE_FACE_NO = 0,
    /**
     * 太近了
     */
    LIVE_FACE_FAR,
    /**
     * 太远了
     */
    LIVE_FACE_NEAR,
    /**
     * 多张人脸
     */
    LIVE_FACE_MANY,
    /**
     * 检测到人脸
     */
    LIVE_FACE_HAVE,
    /**
     * 人脸符合要求
     */
    LIVE_FACE_NOMAL,
    /**
     * 光线太暗了
     *
     */
    LIVE_FACE_NOENOUGH_LIGHT,
    /**
     * 光线太亮了
     *
     */
    LIVE_FACE_TOO_LIGHT,
    /**
     * 手机晃动
     *
     */
    LIVE_FACE_SHAKE,
    /**
     * 请正对屏幕
     *
     */
    LIVE_FACE_POSE_ERROR
};
/**
 *  检测模块类型
 */
typedef NS_ENUM(NSInteger, LivefaceDetectionType) {
    
    /**
     *  未定义类型
     */
    LIVE_NONE = 0,
    
    /**
     *  眨眼检测
     */
    LIVE_BLINK,
    
    /**
     *  张嘴检测
     */
    LIVE_MOUTH,
    
    /**
     *  上下点头检测
     */
    LIVE_NOD,
    
    /**
     *  左右转头检测
     */
    LIVE_YAW
};


/**
 *  输出方案
 */
typedef NS_ENUM(NSUInteger, LivefaceOutputType) {
    
    /**
     *  单图方案
     */
    LIVE_OUTPUT_SINGLE_IMAGE,
    
    /**
     *  多图方案
     */
    LIVE_OUTPUT_MULTI_IMAGE,
    
};


/**
 *  活体检测复杂度
 */
typedef NS_ENUM(NSUInteger, LivefaceComplexity) {
    
    /**
     *  简单, 人脸变更时不会回调 LIVENESS_FACE_CHANGED 错误, 活体阈值低
     */
    LIVE_COMPLEXITY_EASY,
    
    /**
     *  一般, 人脸变更时会回调 LIVENESS_FACE_CHANGED 错误, 活体阈值较低
     */
    LIVE_COMPLEXITY_NORMAL,
    
    /**
     *  较难, 人脸变更时会回调 LIVENESS_FACE_CHANGED 错误, 活体阈较高
     */
    LIVE_COMPLEXITY_HARD,
    
    /**
     *  困难, 人脸变更时会回调 LIVENESS_FACE_CHANGED 错误, 活体阈值高
     */
    LIVE_COMPLEXITY_HELL
};

/**
 *  视频质量
 */
typedef NS_ENUM(NSUInteger, LivefaceVideoQualityType) {
    
    /**
     *  低质量视频方案
     */
    LIVE_LOW_QUALITY_VIDEO,
    
    /**
     *  高质量视频方案
     */
    LIVE_HIGH_QUALITY_VIDEO
    
};

#endif /* LFLivenessEnumType_h */
